@@ -1,4 +1,4 @@
--- $Id: stored.sql 38912 2013-02-27 16:02:35Z wsl $
+-- $Id: stored.sql 39769 2013-07-09 07:46:47Z wsl $
 -- $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/doc/stored.sql $
 
 \encoding UTF8
@@ -530,11 +530,11 @@ CREATE OR REPLACE FUNCTION fsck(ifix BOOL) RETURNS SETOF TEXT AS $$
 			END IF;
 		END LOOP;
 
-		-- canonicalvelden moeten uniek zijn
-		-- FIXME
-
 		-- canonicalvelden moeten niet NULL zijn
-		-- FIXME
+		FOR p_person IN SELECT p.person FROM persons WHERE canonical IS NULL
+		LOOP
+			RETURN NEXT 'Person ' || p_person || ' does not have a canonical alias set';
+		END LOOP;
 
 		-- external destinations mogen niet verwijzen naar een persons.mailaddress
 		FOR e_alias, p_person, p_address IN SELECT e.mail_alias, p.person, p.mailaddress
