@@ -248,7 +248,7 @@ $(document).ready(function() {
 						setTimeout(function() { self.show() }, 0);
 					}
 				},
-				type: 'DELETE',
+				type: 'DELETE'
 			});
 		});
 
@@ -347,7 +347,7 @@ $(document).ready(function() {
 				name: $name.val(),
 				domain: $domain.val(),
 				destinations: addresses,
-				addressbook: text2bool(ab, null),
+				addressbook: text2bool(ab, null)
 			};
 			var destinations_by_id = self.destinations_by_id;
 			for(var k in destinations_by_id) {
@@ -360,7 +360,7 @@ $(document).ready(function() {
 				var notes = data.notes;
 				if(notes.update[0] == 'ok') {
 					if(self.alias.name === undefined) {
-						var widget = new AliasWidget();
+						var widget = new AliasWidget({domain: data.alias.domain, destinations: []});
 						widget.$div.hide();
 						$kikiAlias.append(widget.div);
 						widget.$div.slideDown('fast');
@@ -426,11 +426,11 @@ $(document).ready(function() {
 				: 'alias/' + full(self.alias) + qnonce();
 			$.ajax({
 				url: url,
-				data: json(postdata),
+				data: JSON.stringify(postdata),
 				contentType: 'application/json',
 				dataType: 'json',
 				success: success,
-				type: 'POST',
+				type: 'POST'
 			});
 		});
 
@@ -563,7 +563,7 @@ $(document).ready(function() {
 			data: { q: q },
 			success: searchResult,
 			dataType: 'json',
-			type: 'GET',
+			type: 'GET'
 		});
 	}
 
@@ -573,7 +573,7 @@ $(document).ready(function() {
 			success: function(data) { nonce = data.nonce },
 			error: function(data) { if(confirm("Your session seems to have expired. You need to reload the page to be able to continue, but doing so will undo any pending changes you have made. Reload now?")) location.reload() },
 			dataType: 'json',
-			type: 'GET',
+			type: 'GET'
 		});
 	}
 
@@ -606,7 +606,7 @@ $(document).ready(function() {
 		url: 'domains',
 		success: domeinenGeladen,
 		dataType: 'json',
-		type: 'GET',
+		type: 'GET'
 	});
 
 	$(window).bind('hashchange', function() {
